@@ -18,10 +18,10 @@ class MainTimelineModel : public TimelineModel
 
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
     Q_PROPERTY(QString listId READ listId WRITE setListId NOTIFY listIdChanged)
-    Q_PROPERTY(bool atEnd READ atEnd NOTIFY atEndChanged)
     Q_PROPERTY(bool hasPrevious READ hasPrevious NOTIFY hasPreviousChanged)
     Q_PROPERTY(QDateTime lastReadTime READ lastReadTime NOTIFY hasPreviousChanged)
     Q_PROPERTY(bool userHasTakenReadAction READ userHasTakenReadAction NOTIFY userHasTakenReadActionChanged)
+    Q_PROPERTY(QString url READ url WRITE setUrl NOTIFY urlChanged)
 
 public:
     explicit MainTimelineModel(QObject *parent = nullptr);
@@ -48,6 +48,9 @@ public:
      */
     void setListId(const QString &id);
 
+    QString url() const;
+    void setUrl(const QString &url);
+
     void fillTimeline(const QString &fromId, bool backwards = false) override;
     [[nodiscard]] QString displayName() const override;
     void handleEvent(AbstractAccount::StreamingEventType eventType, const QByteArray &payload) override;
@@ -55,26 +58,30 @@ public:
 
     QVariant data(const QModelIndex &index, int role) const override;
 
-    [[nodiscard]] bool atEnd() const;
     [[nodiscard]] bool hasPrevious() const;
     [[nodiscard]] QDateTime lastReadTime() const;
     [[nodiscard]] bool userHasTakenReadAction() const;
 
     void reset() override;
     bool loading() const override;
+    bool atEnd() const override;
 
     Q_INVOKABLE void fetchPrevious();
     Q_INVOKABLE void updateReadMarker(const QString &postId);
 
+public Q_SLOTS:
+    void refresh() override;
+
 Q_SIGNALS:
-    void atEndChanged();
     void listIdChanged();
     void hasPreviousChanged();
     void userHasTakenReadActionChanged();
+    void urlChanged();
 
 private:
     QString m_timelineName;
     QString m_listId;
+    QString m_url;
 
     std::optional<QUrl> m_next, m_prev;
     QString m_lastReadId, m_initialLastReadId;
